Sharad Mishra wrote:
# HG changeset patch
# User Sharad Mishra <snmishra(a)us.ibm.com>
# Date 1259886908 28800
# Node ID 9d767d98ffbf90aaf06f714581f210d17cfca9cb
# Parent 45c6da8ca664a61a727b0c0d1811c4337efb53b0
[TEST] (#2) Changes to vxml for IPv6 Support
#2: Name changes, ipv6 to ipv6_flag and IsIPv6Only to is_ipv6_only
Signed-off-by: Sharad Mishra <snmishra(a)us.ibm.com>
diff -r 45c6da8ca664 -r 9d767d98ffbf suites/libvirt-cim/lib/XenKvmLib/vxml.py
--- a/suites/libvirt-cim/lib/XenKvmLib/vxml.py Tue Dec 01 16:08:15 2009 -0800
+++ b/suites/libvirt-cim/lib/XenKvmLib/vxml.py Thu Dec 03 16:35:08 2009 -0800
@@ -569,7 +569,7 @@
def __init__(self, virt, dom_name, uuid, pae, acpi, apic, disk_dev,
disk_source, net_type, net_name, net_mac, vcpus, mem,
mem_allocunits, emu_type, grstype, ip,
port_num, kmap, irstype, btype, vnc_passwd):
self.virt = virt
self.domain_name = dom_name
self.err_rc = None
@@ -591,6 +591,7 @@
dom_name, emu_type)
self.gasd = vsms.get_gasd_class(virt)(name=dom_name,
res_sub_type=grstype, ip=ip,
+ ipv6_flag=is_ipv6_only,
lport=port_num, keymap=kmap,
vnc_passwd=vnc_passwd)
self.masd = vsms.get_masd_class(virt)(megabytes=mem,
@@ -813,7 +814,8 @@
disk=const.Xen_default_disk_dev,
ntype=const.default_net_type,
net_name=const.default_network_name,
- emu_type=None, grstype="vnc",
address="127.0.0.1",
+ emu_type=None, grstype="vnc", address=None,
+ is_ipv6_only=True,
I'm sorry, I didn't catch this on the past reviews. This should
probably default to None, otherwise all the guests that get created by
existing tests will have IPv6 ip addresses. This differs from
@@ -569,7 +569,7 @@
disk_source, net_type, net_name, net_mac, vcpus, mem,
mem_allocunits, emu_type, grstype, ip,
- port_num, kmap, irstype, btype, vnc_passwd):
+ is_ipv6_only, port_num, kmap, irstype, btype, vnc_passwd):
self.virt = virt
self.domain_name = dom_name
libvirt-cim's default behavior.
Thanks!
--
Kaitlin Rupert
IBM Linux Technology Center
kaitlin(a)linux.vnet.ibm.com